@@ -1,5 +1,6 @@
 import pytest
 
+import hickle
 import logging
 from bidict import bidict
 from pathlib import Path
@@ -23,7 +24,7 @@ def test_dir(tmp_path_factory):
     return test_env(tmp_path_factory)
 
 
-@pytest.fixture(scope="module")
+@pytest.fixture(scope="function")
 def test_env(tmp_path_factory):
     # Create an ideal observation file using tmp_path_factory
     pthList = ["Spectra", "Resistance", "S11"]
@@ -112,24 +113,21 @@ def test_env(tmp_path_factory):
 
 
 # function to make observation object
-def new_test_obs(testdir):
-    return io.CalibrationObservation(testdir)
-
-
-# directory testing
-def test_make_good_obs(test_env, caplog):
-    # test that correct layouts pass (make an obs)
-    new_test_obs(test_env)
+@pytest.fixture(scope="function")
+def calio(test_env):
+    return io.CalibrationObservation(test_env)
 
 
 def test_bad_dirname_obs(test_env, caplog):
     # test that incorrect directories fail
+
     test_dir = test_env
     base = test_dir.parent
+
     wrong_dir = base / "Receiver_2020_01_01_010_to_200MHz"
     test_dir.rename(wrong_dir)
     with pytest.raises(utils.FileStructureError):
-        new_test_obs(wrong_dir)
+        io.CalibrationObservation(wrong_dir)
     print(caplog.text)
     assert (
         "The filename Receiver_2020_01_01_010_to_200MHz does not have the correct format"
@@ -141,55 +139,55 @@ def test_bad_dirname_obs(test_env, caplog):
     wrong_dir = base / "Receiver00_25C_2020_01_01_010_to_200MHz"
     test_dir.rename(wrong_dir)
     print("WRONGDIR: ", wrong_dir)
-    new_test_obs(wrong_dir)
+    io.CalibrationObservation(wrong_dir)
     assert "Unknown receiver number" in caplog.text
 
     # year
     test_dir = wrong_dir
     wrong_dir = base / "Receiver01_25C_2009_01_01_010_to_200MHz"
     test_dir.rename(wrong_dir)
-    new_test_obs(wrong_dir)
+    io.CalibrationObservation(wrong_dir)
     assert "Unknown year" in caplog.text
 
     test_dir = wrong_dir
     wrong_dir = base / "Receiver01_25C_2045_01_01_010_to_200MHz"
     test_dir.rename(wrong_dir)
-    new_test_obs(wrong_dir)
+    io.CalibrationObservation(wrong_dir)
     assert "Unknown year" in caplog.text
 
     # month
     test_dir = wrong_dir
     wrong_dir = base / "Receiver01_25C_2020_13_01_010_to_200MHz"
     test_dir.rename(wrong_dir)
-    new_test_obs(wrong_dir)
+    io.CalibrationObservation(wrong_dir)
     assert "Unknown month" in caplog.text
 
     # day
     test_dir = wrong_dir
     wrong_dir = base / "Receiver01_25C_2020_01_32_010_to_200MHz"
     test_dir.rename(wrong_dir)
-    new_test_obs(wrong_dir)
+    io.CalibrationObservation(wrong_dir)
     assert "Unknown day" in caplog.text
 
     # freqlow
     test_dir = wrong_dir
     wrong_dir = base / "Receiver01_25C_2020_01_01_000_to_200MHz"
     test_dir.rename(wrong_dir)
-    new_test_obs(wrong_dir)
+    io.CalibrationObservation(wrong_dir)
     assert "Low frequency is weird" in caplog.text
 
     # freqhigh
     test_dir = wrong_dir
     wrong_dir = base / "Receiver01_25C_2020_01_01_010_to_900MHz"
     test_dir.rename(wrong_dir)
-    new_test_obs(wrong_dir)
+    io.CalibrationObservation(wrong_dir)
     assert "High frequency is weird" in caplog.text
 
     # freqrange
     test_dir = wrong_dir
     wrong_dir = base / "Receiver01_25C_2020_01_01_200_to_010MHz"
     test_dir.rename(wrong_dir)
-    new_test_obs(wrong_dir)
+    io.CalibrationObservation(wrong_dir)
     assert "Low frequency > High Frequency" in caplog.text
 
 
@@ -314,3 +312,10 @@ def test_spec_matches(datadir):
 def test_field_spectrum_read_bad_suffix(datadir):
     with pytest.raises(TypeError, match="must be h5 or acq"):
         io.FieldSpectrum(datadir / "observation.yaml")
+
+
+def test_hickle_roundtrip(calio, tmpdir):
+    hickle.dump(calio, tmpdir / "tmp-calio.h5")
+    new = hickle.load(tmpdir / "tmp-calio.h5")
+
+    assert new == calio
